#
# spec file for package stellarsolver
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
%define min_sover 4

Name:           stellarsolver
Version:        2.4
Release:        bp155.1.15
Summary:        Astrometric Solver
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Astronomy
URL:            https://github.com/rlancaste/stellarsolver
Source0:        https://github.com/rlancaste/stellarsolver/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(wcslib)

%description
An Astrometric Plate Solver for Mac, Linux, and Windows,
built on Astrometry.net and SEP (sextractor).

%package -n stellarbatchsolver
Summary:        Batch images solver based on stellarsolver

%description  -n stellarbatchsolver
Tool that one could use to automatically solve, extract, and export a large number of images.
This program is primarily meant for data reduction, but could also be used as a test for the library.

%package -n libstellarsolver%{sover}
Summary:        Astrometric Solver runtime library
Group:          System/Libraries

%description  -n libstellarsolver%{sover}
An Astrometric Plate Solver for Mac, Linux, and Windows,
built on Astrometry.net and SEP (sextractor), runtime library.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libstellarsolver%{sover} = %{version}

%description devel
Development headers and libraries for %{name}.

%lang_package

%prep
%autosetup -p1
find . -name *DS_Store -delete
sed -i 's/Version=1.4/Version=1.0/' stellarbatchsolver/com.github.rlancaste.stellarbatchsolver.desktop

%build
%cmake \
  -DCMAKE_INSTALL_LIBDIR=%{_lib} \
  -DBUILD_BATCH_SOLVER=On
%cmake_build

%install
%cmake_install

%post -n libstellarsolver%{sover} -p /sbin/ldconfig
%postun -n libstellarsolver%{sover} -p /sbin/ldconfig

%files -n stellarbatchsolver
%{_bindir}/StellarBatchSolver
%{_datadir}/applications/com.github.rlancaste.stellarbatchsolver.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/128x128/
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/64x64/
%dir %{_datadir}/icons/hicolor/64x64/apps
%dir %{_datadir}/icons/hicolor/48x48/
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/32x32/
%dir %{_datadir}/icons/hicolor/32x32/apps
%dir %{_datadir}/icons/hicolor/16x16/
%dir %{_datadir}/icons/hicolor/16x16/apps
%{_datadir}/icons/hicolor/128x128/apps/StellarBatchSolverIcon.png
%{_datadir}/icons/hicolor/16x16/apps/StellarBatchSolverIcon.png
%{_datadir}/icons/hicolor/32x32/apps/StellarBatchSolverIcon.png
%{_datadir}/icons/hicolor/48x48/apps/StellarBatchSolverIcon.png
%{_datadir}/icons/hicolor/64x64/apps/StellarBatchSolverIcon.png

%files -n libstellarsolver%{sover}
%license LICENSE
%{_libdir}/libstellarsolver.so.%{sover}
%{_libdir}/libstellarsolver.so.%{sover}.%{min_sover}

%files devel
%license LICENSE
%{_includedir}/libstellarsolver/
%{_libdir}/cmake/StellarSolver/
%{_libdir}/libstellarsolver.so
%{_libdir}/pkgconfig/stellarsolver.pc

%changelog
* Mon Aug  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.4:
  * Make sure stellarsolver does not run after its deleted.
  * Adding an abort and wait function that will wait synchronously, if desired.
  * Add parallel abort support.
  * Preventing program freezes and improving messages.
* Thu Jun 16 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.3:
  * It can now selected the color channel one would like to extract or solve,
    if it is an RGB image, or one can select to integrate or average the channels.
  * Add StellarBatchSolver, a tool that can be used to automatically solve, extract,
    and export a large number of images.
  * Improvements to memory management.
  * Performance improvements.
  * Bug fixes.
* Wed Mar 16 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.2:
  * fix valgrind issues
  * improve memory management
  * correcting downsample in WCSData
* Thu Mar 10 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.1:
  * fix for watney solver
  * remove wrong options from watney solver
  * add ability to abort on internal star extraction
  * detect ASTAP in /usr/bin
  * add support for saving results
  * avoid name conflict in includes in Kstars
  * fix crash that may happen during logging
  * fix solver paths
* Thu Mar  3 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0:
  * Eliminating the last external files: solved and cancel files from the internal solver
  * Making an interface between the C++ and astrometry.net logging that works well to fix logging issues
  * Making StellarSolver easier to use in a blocking way, including using it as a C++ temporary object
  * Making the convolution filter easier to generate and use as well as adding more types of filters
  * Significantly reducing the astrometry code needed for the solver
  * Adding support for a new external solver: the Watney Astrometry Solver
  * Improving the abort code so that it shuts down faster
  * Adding a number of demos to show how to use StellarSolver
  * Adding healpix and index series hints so that you can speed up solves in localized areas based on former solves
  * Making it possible to run two stellar solvers simultaneously
  * Adding some new options for star extraction
  * Making API simplifications
  * Fixing some memory leaks and other warnings on various operating systems
  * Removing some unused code
- Remove fix-version.patch
* Mon Jan 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9:
  * use C locale for numbers
  * fixed some warnings
  * enclosing the deprecated code corrections in qt version check ifdefs
- Add fix-version.patch
* Mon Aug 30 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8:
  * it is now possible to use the external astrometry.net
    local solver without it needing to invoke python
  * fixes and improvements wrt astrometry.net
  * protect against malformed subframes that might lead to crashes
  * fix parity calculations for ASTAP and Local Astrometry.net
* Mon May 17 2021 Paolo Stivanin <info@paolostivanin.com>
- Fix License as, according to
  https://github.com/rlancaste/stellarsolver/blob/master/LICENSE#L640,
  it should be GPL 3.0 or later and not GPL 3.0 only.
* Fri Nov 27 2020 Wolfgang Bauer <wbauer@tmo.at>
- Initial package
